@@ -2,7 +2,7 @@ import logging
 
 from bitfield import BitField, BitHandler
 from django.conf import settings
-from django.db import transaction
+from django.db import transaction, connection
 from django.db.models import PositiveIntegerField, BigIntegerField, UniqueConstraint, Q
 from django.forms import model_to_dict
 
@@ -404,7 +404,7 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
     def get_queryset(self):
         return ItemQuerySet(self.model, using=self._db)
 
-    def checkRecursives(self, request, ):
+    def checkRecursives(self, request):
         from kaf_pas.ckk.management.commands.check_item_cicular_refs import check_level
         from isc_common.models.deleted_progresses import Deleted_progresses
 
@@ -433,6 +433,46 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
                     raise ex
         raise Exception(f'Not data.')
 
+    @staticmethod
+    def _getQtyChilds(records):
+        from kaf_pas.ckk.models.item_qty import Item_qty
+
+        res = 0
+        if isinstance(records, list):
+            with connection.cursor() as cursor:
+                for record in records:
+                    cursor.execute(f'''WITH RECURSIVE r AS (
+                                                                SELECT *, 1 AS level
+                                                                FROM ckk_item_refs
+                                                                WHERE parent_id IN (%s)
+    
+                                                                union all
+    
+                                                                SELECT ckk_item_refs.*, r.level + 1 AS level
+                                                                FROM ckk_item_refs
+                                                                         JOIN r
+                                                                              ON ckk_item_refs.parent_id = r.child_id)
+    
+                                                            select  count(*)
+                                                            from r''', [record.get('id')])
+                    qty, = cursor.fetchone()
+                    res += qty
+                    Item_qty.objects.create(
+                        child_id=record.get('id'),
+                        parent_id=record.get('parent_id'),
+                        qty=qty
+                    )
+        return dict(qty=res)
+
+    def getQtyChilds(self, request):
+
+        request = DSRequest(request=request)
+        data = request.get_data()
+        if isinstance(data, dict):
+            records = data.get('records')
+            if isinstance(records, list):
+                return ItemManager._getQtyChilds(records=records)
+
 
 class Item_add:
     @staticmethod
