@@ -1,6 +1,7 @@
 import logging
 
 from bitfield import BitField
+from django.db import connection, transaction
 from django.db.models import Q, UniqueConstraint, CheckConstraint, F
 
 from isc_common.fields.related import ForeignKeyProtect
@@ -14,7 +15,27 @@ logger = logging.getLogger(__name__)
 
 
 class Item_refsQuerySet(AuditQuerySet):
-    pass
+    def has_child_entered(self, id):
+        with connection.cursor() as cursor:
+            cursor.execute('''select count(*)
+                                   from ckk_item_refs
+                                   where child_id = %s''', [id])
+            cnt, = cursor.fetchone()
+            return cnt > 0
+
+    def delete(self):
+        return super().delete()
+
+    def delete_with_checked(self):
+        from kaf_pas.ckk.views.item_view import audo_top_level
+        with transaction.atomic():
+            for item_ref in self:
+                if not self.has_child_entered(id=item_ref.child.id):
+                    Item_refs.objects1.create(child=item_ref.child, parent_id=int(audo_top_level))
+            return super().delete()
+
+    def get_or_create(self, defaults=None, **kwargs):
+        return super().get_or_create(defaults=defaults, **kwargs)
 
 
 class Item_refsManager(AuditManager):
@@ -56,6 +77,7 @@ class Item_refs(Hierarcy):
     props = Item_refsManager.props()
 
     objects = TreeAuditModelManager()
+    objects1 = Item_refsManager()
 
     def __str__(self):
         return f'\nID={self.id}, child=[{self.child}], parent=[{self.parent}]'
