@@ -101,6 +101,8 @@ class Document_attributesQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
     @staticmethod
     def get_or_create_attribute(attr_codes, value_str, attr_names=None, logger=None):
+        from django.conf import settings
+        settings.LOCKS.acquire('Document_attributesManager.get_or_create_attribute')
         attr_type = AttrManager.get_or_create_attr(attr_codes=attr_codes, attr_names=attr_names, logger=logger)
         value_int = None
         try:
@@ -114,6 +116,7 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
                 value_str=value_str,
                 value_int=value_int
             )
+            settings.LOCKS.release('Document_attributesManager.get_or_create_attribute')
             return attribute, False
         except Document_attributes.DoesNotExist:
             attribute = Document_attributes.objects.create(
@@ -121,6 +124,7 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
                 value_str=value_str,
                 value_int=value_int
             )
+            settings.LOCKS.release('Document_attributesManager.get_or_create_attribute')
             return attribute, True
         except Document_attributes.MultipleObjectsReturned:
             attribute = [attr for attr in Document_attributes.objects.filter(
@@ -128,8 +132,10 @@ class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
                 value_str=value_str,
                 value_int=value_int
             )][0]
+            settings.LOCKS.release('Document_attributesManager.get_or_create_attribute')
             return attribute, False
 
+
     def get_queryset(self):
         return Document_attributesQuerySet(self.model, using=self._db)
 
