@@ -87,12 +87,13 @@ class DocumentManagerExt:
                         props=Item.props.from_spw
                     ).count()
 
+                    props = Item.props.relevant | Item.props.from_spw
                     parent = Item.objects.create(
                         STMP_1_id=STMP_1.id if STMP_1 else None,
                         STMP_2_id=STMP_2.id if STMP_2 else None,
-                        props=Item.props.relevant | Item.props.from_spw,
+                        props=props,
                         document=document,
-                        version=ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=Item.props.from_cdw) if cnt != 0 else None
+                        version=ItemManager.get_verstion(STMP_1=STMP_1, STMP_2=STMP_2, props=props) if cnt != 0 else None
                     )
 
                     Item_refs.objects.create(parent_id=int(top_level.value), child=parent)
@@ -117,19 +118,26 @@ class DocumentManagerExt:
                                 _SPC_CLM_MARK = f'{SPC_CLM_MARK_old}{SPC_CLM_MARK}'
                                 for document_attribute in Document_attributes.objects.filter(id=SPC_CLM_MARK_ID):
                                     try:
-                                        _document_attribute = Document_attributes.objects.get(attr_type=document_attribute.attr_type, value_str=_SPC_CLM_MARK)
-                                        Document_attr_cross.objects.update_or_create(
-                                            attribute=document_attribute,
-                                            defaults=dict(
+                                        _document_attribute = Document_attributes.objects.get(
+                                            attr_type=document_attribute.attr_type,
+                                            value_str=_SPC_CLM_MARK
+                                        )
+
+                                        try:
+                                            document_attr_cross = Document_attr_cross.objects.filter(
+                                                attribute=document_attribute,
+                                                document=document)[0]
+                                            setAttr(line_specification, 'SPC_CLM_MARK_ID', _document_attribute.id)
+                                        except IndexError:
+                                            Document_attr_cross.objects.create(
                                                 attribute=_document_attribute,
                                                 document=document
-                                            ))
+                                            )
                                         setAttr(line_specification, 'SPC_CLM_MARK_ID', _document_attribute.id)
                                     except Document_attributes.DoesNotExist:
                                         document_attribute.value_str = _SPC_CLM_MARK
                                         document_attribute.save()
 
-
                             elif isinstance(SPC_CLM_MARK, str):
                                 SPC_CLM_MARK_old = SPC_CLM_MARK
 
