@@ -6,6 +6,7 @@ from django.db import transaction
 from isc_common.bit import TurnBitOn
 from isc_common.common import blinkString
 from isc_common.common.mat_views import refresh_mat_view
+from isc_common.datetime import DateTimeToStr
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
 from isc_common.number import DelProps
@@ -209,46 +210,75 @@ class UploadesManager(AuditManager):
 
         request = DSRequest(request=request)
         data = request.get_data()
+        user = request.user
 
-        res = self.change_conferm(data=data)
+        res = self.change_confirm(data=data, user=user)
 
         return dict(res=res)
 
-    def change_conferm(self, data, kind='confirm'):
+    def change_confirm(self, data, user, kind='confirm'):
         from kaf_pas.kd.models.uploades_documents import Uploades_documents
         from kaf_pas.ckk.models.item import Item
         from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy
 
         res = 0
-        with transaction.atomic():
-            if isinstance(data.get('ids'), list):
-                for upload in Uploades.objects.filter(id__in=data.get('ids')):
-                    for uploades_document in Uploades_documents.objects.filter(upload=upload):
-                        for item in Item.objects.filter(document=uploades_document.document):
+
+        if isinstance(data.get('ids'), list):
+            with managed_progress(
+                    id=f'confirm_{user.id}' if kind == 'confirm' else f'unconfirm_{user.id}',
+                    qty=0,
+                    user=user,
+                    message='Подсчет товарных позиций',
+                    props=TurnBitOn(0, 0)
+            ) as progress:
+                try:
+                    with transaction.atomic():
+                        for upload in Uploades.objects.select_for_update().filter(id__in=data.get('ids')):
+                            for uploades_document in Uploades_documents.objects.filter(upload=upload):
+                                res += Item.objects.filter(document=uploades_document.document).count()
+
+                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document=uploades_document.document):
+                                    res += Item.objects.filter(lotsman_document=lotsman_documents_hierarcy).count()
+
+                            if res == 0:
+                                raise Exception(f'Товарных позиций не найдено.')
+
+                            progress.setQty(qty=res)
                             if kind == 'confirm':
-                                item.props |= Item.props.confirmed
+                                progress.setContentsLabel(content=blinkString(f'Подтверждение закачки {upload.path.drived_absolute_path} от {DateTimeToStr(upload.lastmodified, hours=3)}', blink=False, bold=True))
                             else:
-                                item.props &= ~Item.props.confirmed
-                            item.save()
-                            res += 1
+                                progress.setContentsLabel(content=blinkString(f'Отмена Подтверждения закачки {upload.path.drived_absolute_path} от {DateTimeToStr(upload.lastmodified, hours=3)}', blink=False, bold=True))
+                            for uploades_document in Uploades_documents.objects.filter(upload=upload):
+                                for item in Item.objects.filter(document=uploades_document.document):
+                                    if kind == 'confirm':
+                                        item.props |= Item.props.confirmed
+                                    else:
+                                        item.props &= ~Item.props.confirmed
+                                    item.save()
+                                    if progress.step() != 0:
+                                        raise ProgressDroped
 
-                        for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document=uploades_document.document):
-                            for item in Item.objects.filter(lotsman_document=lotsman_documents_hierarcy):
-                                if kind == 'confirm':
-                                    item.props |= Item.props.confirmed
-                                else:
-                                    item.props &= ~Item.props.confirmed
-                                item.save()
-                                res += 1
+                                for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document=uploades_document.document):
+                                    for item in Item.objects.filter(lotsman_document=lotsman_documents_hierarcy):
+                                        if kind == 'confirm':
+                                            item.props |= Item.props.confirmed
+                                        else:
+                                            item.props &= ~Item.props.confirmed
+                                        item.save()
+                                        if progress.step() != 0:
+                                            raise ProgressDroped
+
+                            if kind == 'confirm':
+                                upload.props |= Uploades.props.confirmed
+                            else:
+                                upload.props &= ~Uploades.props.confirmed
+                            upload.save()
+                        progress.sendMessage(type='refresh_uploads_grid')
+                except ProgressDroped as ex:
+                    from isc_common.models.deleted_progresses import Deleted_progresses
+                    Deleted_progresses.objects.filter(id_progress=progress.id, user=progress.user).delete()
+                    raise ex
 
-                    if res > 0:
-                        if kind == 'confirm':
-                            upload.props |= Uploades.props.confirmed
-                        else:
-                            upload.props &= ~Uploades.props.confirmed
-                        upload.save()
-                    else:
-                        raise Exception(f'Товарных позиций не найдено.')
         return res
 
     def unConfirmationFromRequest(self, request):
@@ -256,8 +286,9 @@ class UploadesManager(AuditManager):
 
         request = DSRequest(request=request)
         data = request.get_data()
+        user = request.user
 
-        res = self.change_conferm(data=data, kind='unconfirm')
+        res = self.change_confirm(data=data, user=user, kind='unconfirm')
 
         return dict(res=res)
 
