@@ -11,5 +11,7 @@ urlpatterns = [
     path('Uploades/Lookup/', uploades.Uploades_Lookup),
     path('Uploades/Info/', uploades.Uploades_Info),
     path('Uploades/Copy', uploades.Uploades_Copy),
+    path('Uploades/Confirmation', uploades.Uploades_Confirmation),
+    path('Uploades/UnConfirmation', uploades.Uploades_UnConfirmation),
 
 ]
